@@ -62,7 +62,7 @@ class Socket:
         self.ping_send = True 
 
 
-    def on_message(self, incomming):
+    def on_message(self, ws, incomming):
         incomming = json.loads(incomming)
         event = incomming['message']
 
@@ -163,13 +163,13 @@ class Socket:
         if self.client.verbose:
             print(f"{Color.WARNING}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()}", incomming, f" was not fetched!{Color.ENDC}")
     
-    def on_error(self, *args, **kwargs):
+    def on_error(self, ws, *args, **kwargs):
         print(f"{Color.FAIL}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Error with websockets \nClose code:", args, kwargs, f"{Color.ENDC}")
     
-    def on_open(self, *args, **kwargs):
+    def on_open(self, ws, *args, **kwargs):
         print(f"{Color.OKGREEN}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Connected with the websockets!{Color.ENDC}")
 
-    def on_close(self, close_status_code, close_msg):
+    def on_close(self, ws, close_status_code, close_msg):
         print(f"{Color.WARNING}[Bubblez.py-websockets-{self.client.prefix_log}] {logTime()} Websockets closed!\nClose code:", close_status_code,"  Close msg:", close_msg, f"{Color.ENDC}")
        
     def connect(self, verify:bool=False):
